import 'dart:typed_data';

import 'package:binarize/binarize.dart';

class _List<T> extends PayloadType<List<T>> {
  const _List(this.type, this.lengthType);

  final PayloadType<T> type;

  final PayloadType<int> lengthType;

  @override
  int length(List<T> value) =>
      lengthType.length(1) + value.fold(0, (p, e) => p + type.length(e));

  @override
  List<T> get(ByteData data, int offset) {
    final length = lengthType.get(data, offset);
    final result = <T>[];
    var currentOffset = offset + lengthType.length(length);
    for (var i = 0; i < length; i++) {
      result.add(type.get(data, currentOffset));
      currentOffset += type.length(result.last);
    }
    return result;
  }

  @override
  void set(List<T> value, ByteData data, int offset) {
    lengthType.set(value.length, data, offset);
    var currentOffset = offset + lengthType.length(value.length);
    for (var i = 0; i < value.length; i++) {
      type.set(value[i], data, currentOffset);
      currentOffset += type.length(value[i]);
    }
  }
}

/// Make the given [type] support a list of [T].
///
/// It stores the length of the list first by using the [lengthType] and then
/// store each element of the list using the [type].
///
/// It has a byte length of `lengthType.length(list.first) + type.length(list)`.
///
/// Usage:
///
/// ```dart
/// payload.set(list(uint8), [1, 2 ,3, 4]);
/// ```
PayloadType<List<T>> list<T>(
  PayloadType<T> type, {
  PayloadType<int> lengthType = uint32,
}) =>
    _List(type, lengthType);
